# -*- coding: utf-8 -*-

from __future__ import (print_function, absolute_import,
                        division, unicode_literals)

__author__ = 'Andreas Stelzer'
__email__ = 'ga63nep@mytum.de'
__version__ = '0.1.0'

from .fastlogranktest import logrank_test, multi_logrank_test
